@@ -37,7 +37,7 @@
 
 extern zend_object_handlers php_qt_handler;
 extern zend_class_entry* qstring_ce;
-extern Smoke::Index cachedQObjectSmokeId;
+extern Smoke::ModuleIndex cachedQObjectSmokeId;
 
 zend_class_entry* qobject_ce;
 QHash<const void*, smokephp_object*> SmokeQtObjects;
@@ -318,7 +318,7 @@ bool PHPQt::qt_metacall(smokephp_object* o, Smoke::Stack args)
             * We go through QMetaObject::activate, because it can either be connected to a C++ Slot or a user space Slot
             * cast to a QObject using smoke cast
             * */
-            QObject* ptr = (QObject*) o->smoke()->cast( const_cast<void*>( o->ptr() ), o->classId(), cachedQObjectSmokeId );
+            QObject* ptr = (QObject*) o->smoke()->cast( const_cast<void*>( o->ptr() ), Smoke::ModuleIndex(o->smoke(), o->classId()), cachedQObjectSmokeId );
             void *_b[] = { 0, ((void**) args[3].s_voidp)[1] };
             QMetaObject::activate( ptr, staticMetaObject, 0, _b );
             return true; // success
@@ -328,19 +328,13 @@ bool PHPQt::qt_metacall(smokephp_object* o, Smoke::Stack args)
 }
 
 // time critical
-extern Smoke::Index cachedQObjectSmokeId;
-bool PHPQt::isQObject(const Smoke::Index classId)
+extern Smoke::ModuleIndex cachedQObjectSmokeId;
+bool PHPQt::isQObject(const Smoke::ModuleIndex classId)
 {
     if( classId == cachedQObjectSmokeId )
         return true;
 
-    const Smoke* smoke = PHPQt::smoke();
-    for(Smoke::Index *p = smoke->inheritanceList + smoke->classes[classId].parents; *p; p++)
-    {
-        if( PHPQt::isQObject(*p) )
-            return true;
-    }
-    return false;
+    return Smoke::isDerivedFrom(classId, cachedQObjectSmokeId);
 }
 
 // time critical
@@ -454,7 +448,7 @@ QByteArray PHPQt::getSignature(const int argc, zval **argv, MocArgument* mocStac
 SmokeBinding *qt_binding;
 Smoke::Index PHPQt::findMethod( const char* className, const char* methodName, const int argc, zval** args )
 {
-    Smoke::ModuleIndex method = PHPQt::smoke()->findMethod(className, methodName); // qt_Smoke->methods
+    Smoke::ModuleIndex method = PHPQt::smoke()->findMethod(className, methodName); // qtcore_Smoke->methods
     Smoke::Index i = PHPQt::smoke()->methodMaps[ method.index ].method;
 
     if(i <= 0)
@@ -536,14 +530,14 @@ Smoke::Index PHPQt::findMethod( const char* className, const char* methodName, c
     return i;
 }
 
-void PHPQt::callCppMethod(void *obj, const Smoke::Index method, Smoke::Stack qargs)
+void PHPQt::callCppMethod(void *obj, const Smoke::ModuleIndex& method, Smoke::Stack qargs)
 {
-    const Smoke::Method *m = PHPQt::smoke()->methods + method;
-    const Smoke::ClassFn fn = PHPQt::smoke()->classes[m->classId].classFn;
+    const Smoke::Method *m = method.smoke->methods + method.index;
+    const Smoke::ClassFn fn = method.smoke->classes[m->classId].classFn;
     fn(m->method, obj, qargs);
 }
 
-extern Smoke* qt_Smoke;
+extern Smoke* qtcore_Smoke;
 QList<MocArgument*> PHPQt::QtToMoc( Smoke* smoke, void** a, const QList<QByteArray> methodTypes )
 {
     static QRegExp * rx = 0;
@@ -592,7 +586,7 @@ QList<MocArgument*> PHPQt::QtToMoc( Smoke* smoke, void** a, const QList<QByteArr
                 typeName += "*";
             }
             typeId = smoke->idType( typeName.constData() );
-            smoke = qt_Smoke;
+            smoke = qtcore_Smoke;
             if( typeId == 0 ) {
                 pNotice() << "Cannot handle " << typeName << " as slot argument";
                 return result;
@@ -613,10 +607,10 @@ QList<MocArgument*> PHPQt::QtToMoc( Smoke* smoke, void** a, const QList<QByteArr
     return result;
 }
 
-Smoke* PHPQt::smoke(){ return qt_Smoke; }
+Smoke* PHPQt::smoke(){ return qtcore_Smoke; }
 
-extern SmokeBinding* qt_binding;
-SmokeBinding* PHPQt::binding(){ return qt_binding; }
+extern SmokeBinding* qtcore_binding;
+SmokeBinding* PHPQt::binding(){ return qtcore_binding; }
 
 const char* PHPQt::findRealMethodName(const char* methodName)
 {
