@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 #ifndef __xp_notepad_factory_h__
 #define __xp_notepad_factory_h__
 
 #include <kparts/factory.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kurl.h>
 #include "xparthost_kpart.h"
 
